MatchMakerMonitoring.visible() — alfred3_interact

Skip to main content
`Ctrl`+`K`

# MatchMakerMonitoring.visible()

MatchMakerMonitoring.visible(attr: str) → dict

  Returns the subset of members in the given attribute that should be shown.

  Parameters

    attr (str) – Name of an attribute of the class which returns a dictionary of members. For instance, sections allow ‘all_members’, ‘members’, ‘all_pages’, ‘pages’, and pages allow ‘elements’, ‘all_elements’, ‘input_elements’, ‘filled_input_elements’.